| Title: | Find Tables in Plain Text |
|---|---|
| Description: | The goal of tableguess is to automatically extract table-like objects out of plain text files. |
| Authors: | Jon Harmon [aut, cre] (ORCID: <https://orcid.org/0000-0003-4781-4346>) |
| Maintainer: | Jon Harmon <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-06-03 08:13:02 UTC |
| Source: | https://github.com/jonthegeek/tableguess |
This is likely not the final form and/or name of this function. Right now it requires a character vector that has already been split by newlines, and some guidance on what to do. It does well once you tell it where to look, though.
extract_table( tbl_vctr = character(), merge_empty = TRUE, orientation = c("horizontal", "vertical") )extract_table( tbl_vctr = character(), merge_empty = TRUE, orientation = c("horizontal", "vertical") )
tbl_vctr |
A character vector with one line of text per value. |
merge_empty |
Whether to merge empty cells together (by "row" then by "column"). |
orientation |
Whether the data is laid out horizontally like a tidy table (variables = column names), or vertically (more like a list). |
A data.frame with the extracted table.